==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/CollectorAgentPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.CollectorAgentPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property spnDetails
 */
public data class CollectorAgentPropertiesArgs(
    public val spnDetails: Output<CollectorBodyAgentSpnPropertiesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.CollectorAgentPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.CollectorAgentPropertiesArgs =
        com.pulumi.azurenative.migrate.inputs.CollectorAgentPropertiesArgs.builder()
            .spnDetails(spnDetails?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [CollectorAgentPropertiesArgs].
 */
@PulumiTagMarker
public class CollectorAgentPropertiesArgsBuilder internal constructor() {
    private var spnDetails: Output<CollectorBodyAgentSpnPropertiesArgs>? = null

    /**
     * @param value
     */
    @JvmName("tlthwcsrailtyfkt")
    public suspend fun spnDetails(`value`: Output<CollectorBodyAgentSpnPropertiesArgs>) {
        this.spnDetails = value
    }

    /**
     * @param value
     */
    @JvmName("nyylcahvvqftaalk")
    public suspend fun spnDetails(`value`: CollectorBodyAgentSpnPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.spnDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("irepyqvhauicrpnc")
    public suspend
    fun spnDetails(argument: suspend CollectorBodyAgentSpnPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = CollectorBodyAgentSpnPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.spnDetails = mapped
    }

    internal fun build(): CollectorAgentPropertiesArgs = CollectorAgentPropertiesArgs(
        spnDetails = spnDetails,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/CollectorAgentPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.CollectorAgentPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property spnDetails
 */
public data class CollectorAgentPropertiesArgs(
    public val spnDetails: Output<CollectorBodyAgentSpnPropertiesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.CollectorAgentPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.CollectorAgentPropertiesArgs =
        com.pulumi.azurenative.migrate.inputs.CollectorAgentPropertiesArgs.builder()
            .spnDetails(spnDetails?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [CollectorAgentPropertiesArgs].
 */
@PulumiTagMarker
public class CollectorAgentPropertiesArgsBuilder internal constructor() {
    private var spnDetails: Output<CollectorBodyAgentSpnPropertiesArgs>? = null

    /**
     * @param value
     */
    @JvmName("wnhqiseceetbfukq")
    public suspend fun spnDetails(`value`: Output<CollectorBodyAgentSpnPropertiesArgs>) {
        this.spnDetails = value
    }

    /**
     * @param value
     */
    @JvmName("ncajfckdlhcpdqcx")
    public suspend fun spnDetails(`value`: CollectorBodyAgentSpnPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.spnDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("iwtohoxfxqttmweo")
    public suspend
    fun spnDetails(argument: suspend CollectorBodyAgentSpnPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = CollectorBodyAgentSpnPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.spnDetails = mapped
    }

    internal fun build(): CollectorAgentPropertiesArgs = CollectorAgentPropertiesArgs(
        spnDetails = spnDetails,
    )
}
